# unEQ

CLI application for removing EQ from video files. Supports Equaliser APO configs.

## Requirements

- FFmpeg

## Usage

`uneq -i [video path] -e [eq config path]`

## Limitations

Currently only supports PK (peak), LSC (low shelf) and HSC (high shelf) filter types.
